@@ -39,10 +39,12 @@ OC.L10N.register(
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
+    "Never" : "Nunca",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
+    "Yes" : "Sí",
     "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
     "TURN server protocols" : "Protocolos del servidor TURN",
     "Failed" : "Error",
@@ -56,9 +58,11 @@ OC.L10N.register(
     "Save" : "Guardar",
     "No results" : "Sin resultados",
     "Done" : "Terminado",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "Copy link" : "Copiar enlace",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "You" : "Usted",
     "Collapse" : "Colapsar",
@@ -73,7 +77,6 @@ OC.L10N.register(
     "Restricted" : "Restringido",
     "Personal" : "Personal",
     "Leave conversation" : "Dejar la conversación",
-    "Yes" : "Sí",
     "Delete conversation" : "Eliminar conversación",
     "Password protection" : "Protección con contraseña",
     "Set a password" : "Establecer una contraseña",
@@ -85,9 +88,9 @@ OC.L10N.register(
     "Log in" : "Iniciar sesión",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Home" : "Casa",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
     "Files" : "Archivos",
@@ -95,9 +98,6 @@ OC.L10N.register(
     "Translate" : "Traducir",
     "Dismiss" : "Despedir",
     "Contact" : "Contacto",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "Send message" : "Enviar mensaje",
     "New file" : "Nuevo archivo",
     "Send" : "Enviar",
@@ -113,13 +113,9 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atajos de teclado",
     "Search" : "Buscar",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar su pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Grid view" : "Vista de cuadrícula",
     "Keep" : "Mantener",
     "Submit" : "Enviar",
     "User" : "Usuario",
@@ -132,11 +128,11 @@ OC.L10N.register(
     "Locations" : "Ubicaciones",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Default" : "Predeterminado",
     "Group" : "Grupo",
     "Please reload the page." : "Favor de volver a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Lejos",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
@@ -149,6 +145,11 @@ OC.L10N.register(
     "Tasks" : "Tareas",
     "Notes" : "Notas",
     "Reports" : "Reportes",
-    "Close" : "Cerrar"
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
