@@ -478,12 +478,12 @@ OC.L10N.register(
     "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload" : "העלאה",
     "Files" : "קבצים",
-    "Message sent" : "הודעה נשלחה",
-    "Deleting message" : "ההודעה נמחקה",
     "Reply" : "תגובה",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
     "Dismiss" : "התעלמות",
+    "Message sent" : "הודעה נשלחה",
+    "Deleting message" : "ההודעה נמחקה",
     "Contact" : "איש/אשת קשר",
     "No messages" : "אין הודעות",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
@@ -604,12 +604,9 @@ OC.L10N.register(
     "Tasks" : "משימות",
     "Notes" : "פתקים",
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
-    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
-    "Copy conversation link" : "העתקת קישור דיון",
     "Today" : "היום",
     "Yesterday" : "מחר",
     "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
-    "Close" : "סגירה",
     "Choose devices" : "בחירת התקנים",
     "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
