@@ -3,49 +3,50 @@ OC.L10N.register(
     {
     "a conversation" : "saruna",
     "(Duration %s)" : "(Ilgums %s)",
-    "You attended a call with {user1}" : "Jūs piedalījāties sarunā ar {user1}",
+    "You attended a call with {user1}" : "Tu piedalījies zvanā ar {user1}",
     "_%n guest_::_%n guests_" : ["%n viesi","%n viesi","%n viesi"],
-    "You attended a call with {user1} and {user2}" : "Jūs piedalījāties sarunā ar {user1} un {user2}",
-    "You attended a call with {user1}, {user2} and {user3}" : "Jūs piedalījāties sarunā ar {user1}, {user2} un {user3}",
-    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3} un {user4}",
-    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3}, {user4} un {user5}",
+    "You attended a call with {user1} and {user2}" : "Tu piedalījies zvanā ar {user1} un {user2}",
+    "You attended a call with {user1}, {user2} and {user3}" : "Tu piedalījies zvanā ar {user1}, {user2} un {user3}",
+    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3} un {user4}",
+    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tu piedalījies zvanā ar {user1}, {user2}, {user3}, {user4} un {user5}",
     "_%n other_::_%n others_" : ["%n other","%n cits","%n citi"],
-    "{actor} invited you to {call}" : "{actor} uzaicināja jūs uz {call}",
+    "{actor} invited you to {call}" : "{actor} uzaicināja Tevi {call}",
     "Talk" : "Runāt",
     "Guest" : "Viesis",
     "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
     "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
+    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Saruna **Piezīme sev** ir izmantojama, lai veiktu piezīmes un kopīgotu informāciju starp savām ierīcēm",
     "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Sapulces uzlabotas ar viesu, kuri uzaicināti e-pastā, atpazīšanu, dalībnieku saraksta ievietošanu, aptauju melnraksti un dalībnieku sarakstu lejupielādēšanu.",
     "Talk updates ✅" : "Talk atjauninājumi ✅",
     "{actor} created the conversation" : "{actor} izveidoja sarunu",
     "You created the conversation" : "Tu izveidoji sarunu",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
-    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
+    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Tu pārdēvēji sarunu no \"%1$s\" uz \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Pārvaldītājs pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
     "You removed the description" : "Tu noņēmi aprakstu",
-    "You started a call" : "Jūs sākāt zvanu",
+    "You started a call" : "Tu uzsāki zvanu",
     "{actor} started a call" : "{actor} sācis zvanu",
     "{actor} joined the call" : "{actor} pievienojies zvanam",
-    "You joined the call" : "Jūs pievienojaties zvanam",
+    "You joined the call" : "Tu pievienojies zvanam",
     "{actor} left the call" : "{actor} pameta zvanu",
     "You left the call" : "Tu pameti zvanu",
     "{actor} unlocked the conversation" : "{actor} atslēdz sarunu",
-    "You unlocked the conversation" : "Jūs atslēdzāt sarunu",
+    "You unlocked the conversation" : "Tu atslēdzi sarunu",
     "{actor} locked the conversation" : "{actor} bloķē sarunu",
-    "You locked the conversation" : "Jūs bloķējāt sarunu",
+    "You locked the conversation" : "Tu aizslēdzi sarunu",
     "{actor} allowed guests" : "{actor} atļauj viesus",
-    "You allowed guests" : "Jūs atļaujat viesus",
+    "You allowed guests" : "Tu atļāvi viesus",
     "{actor} disallowed guests" : "{actor} nepieļāva viesus",
-    "You disallowed guests" : "Jūs nepieļāvāt viesus",
+    "You disallowed guests" : "Tu neatļāvi viesus",
     "{actor} set a password" : "{actor} iestatīja paroli",
-    "You set a password" : "Jūs iestatījāt paroli",
+    "You set a password" : "Tu iestatīji paroli",
     "{actor} removed the password" : "{actor} noņēma paroli",
     "You removed the password" : "Tu noņēmi paroli",
     "{actor} added {user}" : "{actor} pievienoja {user}",
-    "You joined the conversation" : "Jūs pievienojaties sarunai",
+    "You joined the conversation" : "Tu pievienojies sarunai",
     "{actor} joined the conversation" : "{actor} pievienojās sarunai",
     "You added {user}" : "Tu pievienoji {user}",
-    "{actor} added you" : "{actor} jūs pievienoja",
+    "{actor} added you" : "{actor} pievienoja Tevi",
     "You left the conversation" : "Tu pameti sarunu",
     "{actor} left the conversation" : "{actor} pameta sarunu",
     "{actor} removed {user}" : "{actor} noņēma {user}",
@@ -54,14 +55,14 @@ OC.L10N.register(
     "You removed {federated_user}" : "Tu noņēmi {federated_user}",
     "You added {phone}" : "Tu pievienoji {phone}",
     "You removed {phone}" : "Tu noņēmi {phone}",
-    "{actor} promoted {user} to moderator" : "{actor} paaugstināja {user} par regulētāju",
-    "You promoted {user} to moderator" : "Jūs paaugstinājāt {user} par regulētāju",
-    "{actor} promoted you to moderator" : "{actor} paaugstināja jūs par regulētāju",
-    "{actor} demoted {user} from moderator" : "{actor} pazemināts {user} no regulētāja",
-    "You demoted {user} from moderator" : "Jūs pazeminājāt {user} no regulētāja",
-    "{actor} demoted you from moderator" : "{actor} pazemināja jūs no regulētāja",
+    "{actor} promoted {user} to moderator" : "{actor} iecēla {user} par satura pārraudzītāju",
+    "You promoted {user} to moderator" : "Tu iecēli {user} par satura pārraudzītāju",
+    "{actor} promoted you to moderator" : "{actor} iecēla Tevi par satura pārraudzītāju",
+    "{actor} demoted {user} from moderator" : "{actor} pazemināja {user} no satura pārraudzītāja",
+    "You demoted {user} from moderator" : "Tu pazemināji {user} no satura pārraudzītāja",
+    "{actor} demoted you from moderator" : "{actor} pazemināja Tevi no satura pārraudzītāja",
     "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
-    "You shared a file which is no longer available" : "Jūs kopīgojāt datni, kas vairs nav pieejama",
+    "You shared a file which is no longer available" : "Tu kopīgoji datni, kas vairs nav pieejama",
     "Message deleted by author" : "Ziņojumu izdzēsa autors",
     "Administration" : "Pārvaldīšana",
     "System" : "Sistēma",
@@ -91,10 +92,10 @@ OC.L10N.register(
     "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
     "A guest sent a message in conversation {call}" : "Viesis nosūtījis ziņojumu sarunā {call}",
     "{user} mentioned you in a private conversation" : "{user} tevi pieminēja privātā sarunā",
-    "{user} mentioned you in conversation {call}" : "{user} pieminēja jūs sarunā {call}",
+    "{user} mentioned you in conversation {call}" : "{user} pieminēja Tevi sarunā {call}",
     "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
-    "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
-    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
+    "A guest mentioned you in conversation {call}" : "Viesis pieminēja Tevi sarunā {call}",
+    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja Tevi uz grupas sarunu: {call}",
     "Join call" : "Pievienoties zvanam",
     "{user} would like to talk with you" : "{user} vēlas runāt ar Tevi",
     "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
@@ -104,6 +105,9 @@ OC.L10N.register(
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
     "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nepareizi uzvedās. Lūgums atgriezties vēlāk.",
     "Failed to delete the account because the trial server is unreachable. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nav sasniedzams. Lūgums atgriezties vēlāk.",
+    "Note to self" : "Piezīme sev",
+    "Let's get started!" : "Sāksim!",
+    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## Sarunas iestatījumu pārvaldīšana\n\nSarunas izvēlnē var piekļūt dažādiem iestatījumiem, lai pārvaldītu savas sarunas. Piemēram:\n* labot informāciju par sarunām;\n* pārvaldīt paziņojumus;\n* pielietot dažādas satura pārraudzības kārtulas;\n* konfigurēt piekļuvi un drošību;\n* iespējot robotprogrammatūru;\n* un vēl.",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Apvienotie Arābu Emirāti",
     "Afghanistan" : "Afganistāna",
@@ -341,6 +345,7 @@ OC.L10N.register(
     "Zambia" : "Zambija",
     "Zimbabwe" : "Zimbabve",
     "Federation" : "Federācija",
+    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nav uzstādīts, tas var novest pie veiktspējas sarežģījumiem, kad izmanto darbvirsmas klientus.",
     "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
     "Conversation not found" : "Saruna nav atrasta",
     "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
@@ -362,14 +367,17 @@ OC.L10N.register(
     "Name" : "Nosaukums",
     "Beta" : "Beta",
     "Permissions" : "Atļaujas",
-    "General settings" : "Vispārīgie iestatījumi",
+    "General settings" : "Vispārīgi iestatījumi",
     "Enable encryption" : "Ieslēgt šifrēšanu",
     "Pending" : "Gaida",
     "Error" : "Kļūda",
+    "Never" : "Nekad",
     "Language" : "Valoda",
     "Country" : "Valsts",
     "Status" : "Status",
     "Created at" : "Izveidots plkst.",
+    "Yes" : "Jā",
+    "No" : "Nē",
     "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
     "Delete this server" : "Izdzēst šo serveri",
     "Test this server" : "Testēt šo serveri",
@@ -387,6 +395,7 @@ OC.L10N.register(
     "Reset" : "Atiestatīt",
     "Back" : "Atpakaļ",
     "Cancel" : "Atcelt",
+    "Now" : "Tagad",
     "Loading …" : "Ielādē…",
     "From" : "No",
     "To" : "Līdz",
@@ -395,18 +404,22 @@ OC.L10N.register(
     "Save" : "Saglabāt",
     "No results" : "Nav iznākuma",
     "Done" : "Pabeigts",
+    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
+    "Grid view" : "Režģa izkārtojums",
     "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
     "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sānjoslas dalībnieku cilnē varat uzaicināt citus lietotājus vai kopīgot šo saiti, lai uzaicinātu citus.",
     "Share this link to invite others!" : "Kopīgojiet šo saiti, lai uzaicinātu citus!",
     "Copy link" : "Ievietot saiti starpliktuvē",
     "Mute audio" : "Izslēgt audio skaņu",
+    "None" : "Nav",
     "Disable video" : "Atspējot video",
     "Enable video" : "Iespējot video",
-    "You" : "Jūs",
+    "You" : "Tu",
     "Show screen" : "Rādīt ekrānu",
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
+    "Manage the list of banned users in this conversation." : "Pārvaldīt šīs sarunas liegto lietotāju sarakstu.",
     "Date:" : "Datums:",
     "Hide details" : "Paslēpt informāciju",
     "Show details" : "Rādīt informāciju",
@@ -420,8 +433,6 @@ OC.L10N.register(
     "Setup overview" : "Uzstādīšanas pārskats",
     "Leave conversation" : "Atstāt sarunu",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
-    "No" : "Nē",
-    "Yes" : "Jā",
     "Delete conversation" : "Izdzēst sarunu",
     "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
     "Password protection" : "Password protection",
@@ -430,17 +441,20 @@ OC.L10N.register(
     "Delete" : "Izdzēst",
     "Notifications" : "Paziņojumi",
     "Join" : "Pievienoties",
+    "Hello, {displayName}" : "Sveiciens, {displayName}!",
     "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
-    "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
+    "You need to promote a new moderator before you can leave the conversation." : "Ir nepieciešams iecelt jaunu satura pārraudzītāju, lai Tu varētu pamest sarunu.",
+    "Home" : "Sākums",
     "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
     "Clear filter" : "Notīrīt atlasi",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
+    "Teams" : "Komandas",
     "Open conversations" : "Atvērt sarunas",
-    "None" : "Nav",
+    "Users and teams" : "Lietotāji un komandas",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
     "Invalid path selected" : "Atlasīts nederīgs ceļš",
@@ -448,27 +462,28 @@ OC.L10N.register(
     "Files" : "Datnes",
     "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
     "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
+    "Message forwarded to \"Note to self\"" : "Ziņojums pārvirzīts uz “Piezīme sev”",
+    "Error while forwarding message to \"Note to self\"" : "Kļūda ziņojuma pārvirzīšanas uz “Piezīme sev” laikā",
     "Reply" : "Atbildēt",
     "Go to file" : "Doties uz datni",
     "Translate" : "Tulkot",
     "Dismiss" : "Atmest",
-    "Contact" : "Kontakts",
-    "Today" : "Šodien",
-    "Yesterday" : "Vakar",
-    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Contact" : "Kontaktpersona",
     "File to share" : "Kopīgojamā datne",
     "Upload from device" : "Augšupielādēt no ierīces",
     "New file" : "Jauna datne",
+    "Add more files" : "Pievienot vairāk datņu",
     "Send" : "Sūtīt",
     "Settings" : "Iestatījumi",
-    "moderator" : "moderators",
+    "moderator" : "satura pārraudzītājs",
     "guest" : "viesis",
     "Remove participant" : "Noņemt dalībnieku",
-    "Demote from moderator" : "Pazemināt no regulētāja",
-    "Promote to moderator" : "Paaugstināt par regulētāju",
+    "Demote from moderator" : "Pazemināt no satura pārraudzītāja",
+    "Promote to moderator" : "Iecelt par satura pārraudzītāju",
     "Remove" : "Noņemt",
     "Add users or groups" : "Add users or groups",
+    "Add users or teams" : "Pievienot lietotājus vai komandas",
+    "Add teams" : "Pievienot komandas",
     "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
     "Chat" : "Tērzēt",
@@ -492,20 +507,16 @@ OC.L10N.register(
     "Screensharing options" : "Ekrāna kopīgošanas iespējas",
     "Enable screensharing" : "Iespējot ekrāna kopīgošanu",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
-    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
     "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
     "Show your screen" : "Rādīt savu ekrānu",
     "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
-    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
-    "Grid view" : "Režģa izkārtojums",
     "Start recording" : "Uzsākt ierakstīšanu",
     "Open Calendar" : "Atvērt kalendāru",
     "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
     "Keep" : "Paturēt",
-    "Select a region" : "Izvēlieties reģionu",
+    "Select a region" : "Atlasīt apgabalu",
     "Submit" : "Iesniegt",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Duplicate session" : "Pavairot sesiju",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
     "User" : "Lietotājs",
@@ -518,21 +529,24 @@ OC.L10N.register(
     "Polls" : "Aptaujas",
     "Audio" : "Audio",
     "Other" : "Cits",
+    "Show all files" : "Parādīt visas datnes",
     "Show all polls" : "Parādīt visas aptaujas",
+    "Default" : "Noklusējuma",
     "Group" : "Grupa",
+    "Team" : "Komanda",
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
-    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
-    "Default" : "Noklusējuma",
-    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
+    "Please reload the page." : "Lūgums pārlādēt lapu",
+    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
-    "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
+    "Please move your setup to HTTPS" : "Lūgums pārvietot serveri uz HTTPS",
     "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
-    "WebRTC is not supported in your browser" : "WebRTC netiek atbalstīta jūsu pārlūkprogrammā",
-    "Please use a different browser like Firefox or Chrome" : "Lūdzu, izmantojiet citu pārlūkprogrammu, piemēram Firefox vai Chrome",
+    "WebRTC is not supported in your browser" : "Pārlūkā netiek atbalstīts WebRTC",
+    "Please use a different browser like Firefox or Chrome" : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome",
     "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
-    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
+    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus paroles mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
+    "The password is wrong. Try again." : "Nepareiza parole. Jāmēģina vēlreiz.",
     "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
     "Android app" : "Android lietotne",
     "iOS app" : "iOS lietotne",
@@ -541,11 +555,15 @@ OC.L10N.register(
     "Tasks" : "Uzdevumi",
     "Notes" : "Piezīmes",
     "Reports" : "Atskaites",
-    "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
-    "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
-    "Click the button below to join." : "Noklikšķiniet uz tālāk esošās pogas, lai pievienotos.",
+    "%s invited you to a conversation." : "%s uzaicināja Tevi uz sarunu.",
+    "You were invited to a conversation." : "Tu uzaicinājāt uz sarunu.",
+    "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
-    "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
-    "Close" : "Aizvērt"
+    "Today" : "Šodien",
+    "Yesterday" : "Vakar",
+    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
+    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
