@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
     "Guest" : "I ftuar",
+    "Message deleted by author" : "Mesazhi u fshi nga autori",
     "System" : "Sistem",
     "File is too big" : "Skedari është shumë i madh",
     "Invalid file provided" : "U dha kartelë e pavlefshme",
@@ -172,10 +173,12 @@ OC.L10N.register(
     "Pending" : "Në Pritje të Konfirmimit",
     "Error" : "Error",
     "Blocked" : "I bllokuar",
+    "Never" : "Kurrë",
     "Language" : "Gjuha",
     "Country" : "Vend",
     "Status" : "Status",
     "Created at" : "U krijua në",
+    "Yes" : "Po",
     "TURN server protocols" : "Protokollet e serverit TURN",
     "OK" : "OK",
     "Checking …" : "Duke kontrolluar ...",
@@ -188,9 +191,11 @@ OC.L10N.register(
     "Save" : "Ruaj",
     "No results" : "Asnjë rezultat",
     "Done" : "U bë",
+    "Grid view" : "Pamje galeri",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
     "Copy link" : "Kopjo linkun",
     "Mute audio" : "Mute audio",
+    "None" : "Asnjë",
     "Disable video" : "Çaktivizo video",
     "You" : "Ju",
     "Collapse" : "Tkurre",
@@ -202,7 +207,6 @@ OC.L10N.register(
     "Restricted" : "I/E kufizuar",
     "Personal" : "Personale",
     "Leave conversation" : "Largohuni nga biseda",
-    "Yes" : "Po",
     "Delete conversation" : "Fshijeni bisedën",
     "Password protection" : "Password protection",
     "Set a password" : "Vendosni një fjalëkalim",
@@ -215,20 +219,17 @@ OC.L10N.register(
     "Mark as unread" : "Shënoje si të palexuar",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
+    "Home" : "Kryefaqja",
     "Users" : "Përdoruesit",
     "Groups" : "Grupet",
-    "None" : "Asnjë",
     "Devices" : "Pajisjet",
     "Upload" : "Ngarkoni",
     "Files" : "Skedarët",
-    "Message sent" : "Mesazhi u dërgua",
     "Reply" : "Përgjigju",
     "Translate" : "Përkthe",
     "Dismiss" : "Hiq",
+    "Message sent" : "Mesazhi u dërgua",
     "Contact" : "Kontakt",
-    "Today" : "Sot",
-    "Yesterday" : "Dje",
-    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
     "Send message" : "Dërgo mesazh",
     "Create new poll" : "Krijo sondazh të ri",
     "New file" : "Skedë e re",
@@ -242,14 +243,11 @@ OC.L10N.register(
     "Privacy" : "Privatësia",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
+    "More actions" : "Më tepër veprime ",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
-    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
-    "Grid view" : "Pamje galeri",
     "Keep" : "Mbaje",
     "Submit" : "Dërgo",
     "User" : "Përdorues",
@@ -262,9 +260,9 @@ OC.L10N.register(
     "Polls" : "Sondazhe",
     "Audio" : "Audio",
     "Other" : "Tjetër",
+    "Default" : "E paracaktuar",
     "Group" : "Grup",
     "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
-    "Default" : "E paracaktuar",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
     "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
     "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
@@ -275,6 +273,11 @@ OC.L10N.register(
     "iOS app" : "Aplikacion iOS",
     "__language_name__" : "Shqip",
     "Tasks" : "Detyra",
-    "Close" : "Mbylleni"
+    "Today" : "Sot",
+    "Yesterday" : "Dje",
+    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
+    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj."
 },
 "nplurals=2; plural=(n != 1);");
