@@ -36,6 +36,7 @@ use OCA\Talk\Model\Bot;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Model\Reminder;
 use OCA\Talk\Model\Session;
+use OCA\Talk\Model\Thread;
 use OCA\Talk\Participant;
 use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
@@ -47,12 +48,15 @@ use OCA\Talk\Service\ProxyCacheMessageService;
 use OCA\Talk\Service\ReminderService;
 use OCA\Talk\Service\RoomFormatter;
 use OCA\Talk\Service\SessionService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Share\Helper\Preloader;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\PublicPage;
+use OCP\AppFramework\Http\Attribute\RequestHeader;
 use OCP\AppFramework\Http\Attribute\UserRateLimit;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Services\IAppConfig;
@@ -109,6 +113,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		protected AttachmentService $attachmentService,
 		protected AvatarService $avatarService,
 		protected ReminderService $reminderService,
+		protected ThreadService $threadService,
 		private GuestManager $guestManager,
 		private MessageParser $messageParser,
 		protected Preloader $sharePreloader,
@@ -177,9 +182,15 @@ class ChatController extends AEnvironmentAwareOCSController {
 			return new DataResponse(null, Http::STATUS_CREATED, $headers);
 		}
 
-		$data = $chatMessage->toArray($this->getResponseFormat());
+		try {
+			$threadId = (int)$comment->getTopmostParentId() ?: (int)$comment->getId();
+			$thread = $this->threadService->findByThreadId($this->room->getId(), $threadId);
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+		$data = $chatMessage->toArray($this->getResponseFormat(), $thread);
 		if ($parentMessage instanceof Message) {
-			$data['parent'] = $parentMessage->toArray($this->getResponseFormat());
+			$data['parent'] = $parentMessage->toArray($this->getResponseFormat(), $thread);
 		}
 
 		$headers = [];
@@ -201,6 +212,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * @param int $replyTo Parent id which this message is a reply to
 	 * @psalm-param non-negative-int $replyTo
 	 * @param bool $silent If sent silent the chat message will not create any notifications
+	 * @param string $threadTitle Only supported when not replying, when given will create a thread (requires `threads` capability)
+	 * @param int $threadId Thread id which this message is a reply to without quoting a specific message (ignored when $replyTo is given, also requires `threads` capability)
 	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE|Http::STATUS_TOO_MANY_REQUESTS, array{error: string}, array{}>
 	 *
 	 * 201: Message sent successfully
@@ -215,11 +228,16 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireParticipant]
 	#[RequirePermission(permission: RequirePermission::CHAT)]
 	#[RequireReadWriteConversation]
-	public function sendMessage(string $message, string $actorDisplayName = '', string $referenceId = '', int $replyTo = 0, bool $silent = false): DataResponse {
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
+	public function sendMessage(string $message, string $actorDisplayName = '', string $referenceId = '', int $replyTo = 0, bool $silent = false, string $threadTitle = '', int $threadId = 0): DataResponse {
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
 			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
-			return $proxy->sendMessage($this->room, $this->participant, $message, $referenceId, $replyTo, $silent);
+			return $proxy->sendMessage($this->room, $this->participant, $message, $referenceId, $replyTo, $silent, $threadTitle, $threadId);
 		}
 
 		if (trim($message) === '') {
@@ -245,18 +263,44 @@ class ChatController extends AEnvironmentAwareOCSController {
 			if (!$parentMessage->isReplyable()) {
 				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
 			}
+		} elseif ($threadId !== 0) {
+			if (!$this->threadService->validateThread($this->room->getId(), $threadId)) {
+				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
+			}
 		}
 
 		$this->participantService->ensureOneToOneRoomIsFilled($this->room);
 		$creationDateTime = $this->timeFactory->getDateTime('now', new \DateTimeZone('UTC'));
 
 		try {
-			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, $parent, $referenceId, $silent);
+			$createThread = $replyTo === 0 && $threadId === Thread::THREAD_NONE && $threadTitle !== '';
+			$threadId = $createThread ? Thread::THREAD_CREATE : $threadId;
+			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, $parent, $referenceId, $silent, threadId: $threadId);
+			if ($createThread) {
+				$thread = $this->threadService->createThread($this->room, (int)$comment->getId(), $threadTitle);
+				// Add to subscribed threads list
+				$this->threadService->setNotificationLevel($this->participant->getAttendee(), $thread->getId(), Participant::NOTIFY_DEFAULT);
+
+				$this->chatManager->addSystemMessage(
+					$this->room,
+					$this->participant,
+					$this->participant->getAttendee()->getActorType(),
+					$this->participant->getAttendee()->getActorId(),
+					json_encode(['message' => 'thread_created', 'parameters' => ['thread' => (int)$comment->getId(), 'title' => $thread->getName()]]),
+					$this->timeFactory->getDateTime(),
+					false,
+					null,
+					$comment,
+					true,
+					true
+				);
+			}
 		} catch (MessageTooLongException) {
 			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (IRateLimitExceededException) {
 			return new DataResponse(['error' => 'mentions'], Http::STATUS_TOO_MANY_REQUESTS);
 		} catch (\Exception $e) {
+			$this->logger->warning($e->getMessage());
 			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -271,9 +315,10 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 *
 	 * @param string $objectType Type of the object
 	 * @param string $objectId ID of the object
-	 * @param string $metaData Additional metadata
+	 * @param string $metaData Additional metadata, sample value: `{\"type\":\"geo-location\",\"id\":\"geo:52.5450511,13.3741463\",\"name\":\"Nextcloud Berlin Office\",\"latitude\":\"52.5450511\",\"longitude\":\"13.3741463\"}`
 	 * @param string $actorDisplayName Guest name
 	 * @param string $referenceId Reference ID
+	 * @param int $threadId Thread id which this message is a reply to without quoting a specific message (also requires `threads` capability)
 	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 *
 	 * 201: Object shared successfully
@@ -286,7 +331,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireParticipant]
 	#[RequirePermission(permission: RequirePermission::CHAT)]
 	#[RequireReadWriteConversation]
-	public function shareObjectToChat(string $objectType, string $objectId, string $metaData = '', string $actorDisplayName = '', string $referenceId = ''): DataResponse {
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/share', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
+	public function shareObjectToChat(string $objectType, string $objectId, string $metaData = '', string $actorDisplayName = '', string $referenceId = '', int $threadId = 0): DataResponse {
 		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
 			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
@@ -329,8 +378,17 @@ class ChatController extends AEnvironmentAwareOCSController {
 			],
 		]);
 
+		if ($threadId !== 0) {
+			try {
+				$this->threadService->findByThreadId($this->room->getId(), $threadId);
+			} catch (DoesNotExistException) {
+				// Someone tried to cheat, ignore
+				$threadId = 0;
+			}
+		}
+
 		try {
-			$comment = $this->chatManager->addSystemMessage($this->room, $actorType, $actorId, $message, $creationDateTime, true, $referenceId);
+			$comment = $this->chatManager->addSystemMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, true, $referenceId, threadId: $threadId);
 		} catch (MessageTooLongException $e) {
 			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (\Exception $e) {
@@ -383,6 +441,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * @param 0|1 $includeLastKnown Include the $lastKnownMessageId in the messages when 1 (default 0)
 	 * @param 0|1 $noStatusUpdate When the user status should not be automatically set to online set to 1 (default 0)
 	 * @param 0|1 $markNotificationsAsRead Set to 0 when notifications should not be marked as read (default 1)
+	 * @param int $threadId Limit the chat message list to a given thread
+	 * @psalm-param non-negative-int $threadId
 	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 *
 	 * 200: Messages returned
@@ -392,7 +452,13 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
-	public function receiveMessages(int $lookIntoFuture,
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
+	public function receiveMessages(
+		int $lookIntoFuture,
 		int $limit = 100,
 		int $lastKnownMessageId = 0,
 		int $lastCommonReadId = 0,
@@ -400,7 +466,9 @@ class ChatController extends AEnvironmentAwareOCSController {
 		int $setReadMarker = 1,
 		int $includeLastKnown = 0,
 		int $noStatusUpdate = 0,
-		int $markNotificationsAsRead = 1): DataResponse {
+		int $markNotificationsAsRead = 1,
+		int $threadId = 0,
+	): DataResponse {
 		$limit = min(200, $limit);
 		$timeout = min(30, $timeout);
 
@@ -419,6 +487,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 				$includeLastKnown,
 				$noStatusUpdate,
 				$markNotificationsAsRead,
+				// FIXME support threads in federation $threadId,
 			);
 		}
 
@@ -460,16 +529,16 @@ class ChatController extends AEnvironmentAwareOCSController {
 		 */
 
 		$attendee = $this->participant->getAttendee();
-		if ($lookIntoFuture && $setReadMarker === 1 &&
-			$lastKnownMessageId > $attendee->getLastReadMessage()) {
+		if ($lookIntoFuture && $setReadMarker === 1
+			&& $lastKnownMessageId > $attendee->getLastReadMessage()) {
 			$this->participantService->updateLastReadMessage($this->participant, $lastKnownMessageId);
 		}
 
 		$currentUser = $this->userManager->get($this->userId);
 		if ($lookIntoFuture) {
-			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser, (bool)$includeLastKnown, (bool)$markNotificationsAsRead);
+			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser, (bool)$includeLastKnown, (bool)$markNotificationsAsRead, $threadId);
 		} else {
-			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit, (bool)$includeLastKnown);
+			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit, (bool)$includeLastKnown, $threadId);
 		}
 
 		return $this->prepareCommentsAsDataResponse($comments, $lastCommonReadId);
@@ -491,13 +560,17 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/summarize', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function summarizeChat(
 		int $fromMessageId,
 	): DataResponse {
 		$fromMessageId = max(0, $fromMessageId);
 
-		$supportedTaskTypes = $this->taskProcessingManager->getAvailableTaskTypes();
-		if (!isset($supportedTaskTypes[TextToTextSummary::ID])) {
+		$supportedTaskTypeIds = $this->taskProcessingManager->getAvailableTaskTypeIds();
+		if (!in_array(TextToTextSummary::ID, $supportedTaskTypeIds, true)) {
 			return new DataResponse([
 				'error' => ChatSummaryException::REASON_AI_ERROR,
 			], Http::STATUS_BAD_REQUEST);
@@ -623,6 +696,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 		}
 
 		$this->sharePreloader->preloadShares($comments);
+		$potentialThreadIds = array_map(static fn (IComment $comment) => (int)$comment->getTopmostParentId() ?: (int)$comment->getId(), $comments);
+		$threads = $this->threadService->findByThreadIds($this->room->getId(), $potentialThreadIds);
 
 		$i = 0;
 		$now = $this->timeFactory->getDateTime();
@@ -647,7 +722,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 				$parentIds[$id] = $comment->getParentId();
 			}
 
-			$messages[] = $message->toArray($this->getResponseFormat());
+			$threadId = (int)$comment->getTopmostParentId() ?: $id;
+			$messages[] = $message->toArray($this->getResponseFormat(), $threads[$threadId] ?? null);
 			$commentIdToIndex[$id] = $i;
 			$i++;
 		}
@@ -683,7 +759,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 					$this->messageParser->parseMessage($message);
 
 					if ($message->getVisibility()) {
-						$loadedParents[$parentId] = $message->toArray($this->getResponseFormat());
+						$threadId = (int)$comment->getTopmostParentId() ?: $parentId;
+						$loadedParents[$parentId] = $message->toArray($this->getResponseFormat(), $threads[$threadId] ?? null);
 						$messages[$commentKey]['parent'] = $loadedParents[$parentId];
 						continue;
 					}
@@ -740,6 +817,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * @param int $messageId The focused message which should be in the "middle" of the returned context
 	 * @psalm-param non-negative-int $messageId
 	 * @param int<1, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
+	 * @param int $threadId Limit the chat message list to a given thread
+	 * @psalm-param non-negative-int $threadId
 	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 *
 	 * 200: Message context returned
@@ -749,15 +828,29 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/{messageId}/context', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function getMessageContext(
 		int $messageId,
-		int $limit = 50): DataResponse {
+		int $limit = 50,
+		int $threadId = 0,
+	): DataResponse {
 		$limit = min(100, $limit);
 
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
 			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
-			return $proxy->getMessageContext($this->room, $this->participant, $messageId, $limit);
+			return $proxy->getMessageContext(
+				$this->room,
+				$this->participant,
+				$messageId,
+				$limit,
+				// FIXME support threads in federation $threadId,
+			);
 		}
 
 		$currentUser = $this->userManager->get($this->userId);
@@ -765,9 +858,9 @@ class ChatController extends AEnvironmentAwareOCSController {
 			// Guest in a fully expired chat, no history, just loading the chat from beginning for now
 			$commentsHistory = $commentsFuture = [];
 		} else {
-			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true);
+			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true, $threadId);
 			$commentsHistory = array_reverse($commentsHistory);
-			$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false);
+			$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false, threadId: $threadId);
 		}
 
 		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
@@ -844,6 +937,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireAuthenticatedParticipant]
 	#[RequirePermission(permission: RequirePermission::CHAT)]
 	#[RequireReadWriteConversation]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/{messageId}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function deleteMessage(int $messageId): DataResponse {
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -898,8 +997,15 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
 		$this->messageParser->parseMessage($message);
 
-		$data = $systemMessage->toArray($this->getResponseFormat());
-		$data['parent'] = $message->toArray($this->getResponseFormat());
+		try {
+			$threadId = (int)$comment->getTopmostParentId() ?: (int)$comment->getId();
+			$thread = $this->threadService->findByThreadId($this->room->getId(), $threadId);
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+
+		$data = $systemMessage->toArray($this->getResponseFormat(), $thread);
+		$data['parent'] = $message->toArray($this->getResponseFormat(), $thread);
 
 		$hasBotOrBridge = !empty($this->botService->getBotsForToken($this->room->getToken(), Bot::FEATURE_WEBHOOK));
 		if (!$hasBotOrBridge) {
@@ -936,6 +1042,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireAuthenticatedParticipant]
 	#[RequirePermission(permission: RequirePermission::CHAT)]
 	#[RequireReadWriteConversation]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'PUT', url: '/api/{apiVersion}/chat/{token}/{messageId}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function editMessage(int $messageId, string $message): DataResponse {
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -1009,8 +1121,15 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$parseMessage = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
 		$this->messageParser->parseMessage($parseMessage);
 
-		$data = $systemMessage->toArray($this->getResponseFormat());
-		$data['parent'] = $parseMessage->toArray($this->getResponseFormat());
+		try {
+			$threadId = (int)$comment->getTopmostParentId() ?: (int)$comment->getId();
+			$thread = $this->threadService->findByThreadId($this->room->getId(), $threadId);
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+
+		$data = $systemMessage->toArray($this->getResponseFormat(), $thread);
+		$data['parent'] = $parseMessage->toArray($this->getResponseFormat(), $thread);
 
 		$hasBotOrBridge = !empty($this->botService->getBotsForToken($this->room->getToken(), Bot::FEATURE_WEBHOOK));
 		if (!$hasBotOrBridge) {
@@ -1042,6 +1161,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireModeratorOrNoLobby]
 	#[RequireLoggedInParticipant]
 	#[UserRateLimit(limit: 60, period: 3600)]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/{messageId}/reminder', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function setReminder(int $messageId, int $timestamp): DataResponse {
 		try {
 			// FIXME fail 400 when reminder is after expiration
@@ -1076,6 +1201,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[NoAdminRequired]
 	#[RequireModeratorOrNoLobby]
 	#[RequireLoggedInParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/{messageId}/reminder', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function getReminder(int $messageId): DataResponse {
 		try {
 			$this->validateMessageExists($messageId);
@@ -1109,6 +1240,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[NoAdminRequired]
 	#[RequireModeratorOrNoLobby]
 	#[RequireLoggedInParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/{messageId}/reminder', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
 	public function deleteReminder(int $messageId): DataResponse {
 		try {
 			$this->validateMessageExists($messageId);
@@ -1135,6 +1272,9 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * 200: Reminders returned
 	 */
 	#[NoAdminRequired]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/upcoming-reminders', requirements: [
+		'apiVersion' => '(v1)',
+	])]
 	public function getUpcomingReminders(): DataResponse {
 		if ($this->userId === null) {
 			return new DataResponse([], Http::STATUS_OK);
@@ -1191,7 +1331,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 				continue;
 			}
 
-			$data = $message->toArray($this->getResponseFormat());
+			$data = $message->toArray($this->getResponseFormat(), null);
 
 			if ($participant->getAttendee()->isSensitive()) {
 				$data['message'] = '';
@@ -1248,6 +1388,10 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[NoAdminRequired]
 	#[RequireModeratorParticipant]
 	#[RequireReadWriteConversation]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function clearHistory(): DataResponse {
 		$attendee = $this->participant->getAttendee();
 		if (!$this->participant->hasModeratorPermissions(false)) {
@@ -1272,7 +1416,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$this->messageParser->parseMessage($systemMessage);
 
 
-		$data = $systemMessage->toArray($this->getResponseFormat());
+		$data = $systemMessage->toArray($this->getResponseFormat(), null);
 
 		$bridge = $this->matterbridgeManager->getBridgeOfRoom($this->room);
 
@@ -1295,6 +1439,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[FederationSupported]
 	#[PublicPage]
 	#[RequireAuthenticatedParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/read', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function setReadMarker(?int $lastReadMessage = null): DataResponse {
 		$setToMessage = $lastReadMessage ?? $this->room->getLastMessageId();
 		if ($setToMessage === 0) {
@@ -1344,6 +1493,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[FederationSupported]
 	#[PublicPage]
 	#[RequireAuthenticatedParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/read', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function markUnread(): DataResponse {
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -1403,6 +1557,10 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/share/overview', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function getObjectsSharedInRoomOverview(int $limit = 7): DataResponse {
 		$limit = min(20, $limit);
 
@@ -1456,6 +1614,10 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/share', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function getObjectsSharedInRoom(string $objectType, int $lastKnownMessageId = 0, int $limit = 100): DataResponse {
 		$offset = max(0, $lastKnownMessageId);
 		$limit = min(200, $limit);
@@ -1480,6 +1642,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	protected function getMessagesForRoom(array $messageIds): array {
 		$comments = $this->chatManager->getMessagesForRoomById($this->room, $messageIds);
 		$this->sharePreloader->preloadShares($comments);
+		$potentialThreadIds = array_map(static fn (IComment $comment) => (int)$comment->getTopmostParentId() ?: (int)$comment->getId(), $comments);
+		$threads = $this->threadService->findByThreadIds($this->room->getId(), $potentialThreadIds);
 
 		$messages = [];
 		$comments = $this->chatManager->filterCommentsWithNonExistingFiles($comments);
@@ -1498,7 +1662,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 				continue;
 			}
 
-			$messages[$comment->getId()] = $message->toArray($this->getResponseFormat());
+			$threadId = (int)$comment->getTopmostParentId() ?: (int)$comment->getId();
+			$messages[$comment->getId()] = $message->toArray($this->getResponseFormat(), $threads[$threadId] ?? null);
 		}
 
 		return $messages;
@@ -1520,6 +1685,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[RequireParticipant]
 	#[RequirePermission(permission: RequirePermission::CHAT)]
 	#[RequireReadWriteConversation]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/mentions', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function mentions(string $search, int $limit = 20, bool $includeStatus = false): DataResponse {
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -1539,10 +1709,13 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$results = array_merge_recursive($exactMatches, $results);
 
 		$this->autoCompleteManager->registerSorter(Sorter::class);
+		/** @psalm-suppress InvalidArgument */
 		$this->autoCompleteManager->runSorters(['talk_chat_participants'], $results, [
 			'itemType' => 'chat',
 			'itemId' => (string)$this->room->getId(),
 			'search' => $search,
+			'selfUserId' => $this->userId,
+			'selfCloudId' => $this->userId === null ? $this->federationAuthenticator->getCloudId() : null,
 		]);
 
 		$statuses = [];
