@@ -13,7 +13,7 @@ final class KeyTransformerHasTooManyParameters extends LogicException
     public function __construct(MethodDefinition $method)
     {
         parent::__construct(
-            "Key transformer must have at most 1 parameter, {$method->parameters()->count()} given for `{$method->signature()}`.",
+            "Key transformer must have at most 1 parameter, {$method->parameters->count()} given for `$method->signature`.",
             1701701102,
         );
     }
